"""
package declaration
"""
__title__ = 'meo'
__description__ = 'frequently-used function library'
__version__ = [0, 1, 12]
__url__ = "http://github.com/miaobuao/meo"
__author__ = 'miaobuao'
__author_email__ = 'miaobuao@outlook.com'
__license__ = 'MIT License'
__copyright__ = 'Copyright 2022 miaobuao'
